@@ -2,7 +2,6 @@ from numpy import *
 import inspect
 from operator import itemgetter
 
-
 def procdf(function,allvars,procaxis,dimidx=0):
     iterate = False
     if (dimidx <= len(shape(allvars[0]))):
@@ -23,7 +22,11 @@ def procdf(function,allvars,procaxis,dimidx=0):
         # workaround for memory leak when just running  'dataouttemp = function(allvars)' in case of netcdf file references
         allvarstemp = []
         for evar in allvars:
-            allvarstemp.append(array(evar))
+            if type(evar) != ndarray:
+                allvarstemp.append(evar)
+            else:
+                allvarstemp.append(array(evar))
+        #print allvarstemp
         dataouttemp = function(allvarstemp)
         # end workaround
 
@@ -63,8 +66,6 @@ def multifunc(function,allvars,procaxis,vardims):
                     ....                     
                    ]
     """
-    
-
     # add dimensions to variables (i.e. expand array) 
     #in case they are missing (tbi: make this unnecessary)
     dimcount = len(procaxis) 
@@ -154,12 +155,12 @@ def multifunc(function,allvars,procaxis,vardims):
         allvars[ivar] = transpose(evar,trns)
     # ...
 
-    for ivar,evar in enumerate(allvars):
-        print 'shape after transposition:',evar.shape
+    # for ivar,evar in enumerate(allvars):
+    #     print 'shape after transposition:',evar.shape
 
     dataouttrns,outcoordstrnstmp = procdf(function,allvars,trnsprocaxis)
 
-    print 'dataouttrns',shape(dataouttrns)
+    # print 'dataouttrns',shape(dataouttrns)
 
 
     #print('shapedataouttrns', shape(dataouttrns), outcoordstrnstmp)
